Module: Amp
- Defined in:
- lib/amp-front/help/help.rb,
lib/amp-front.rb,
lib/amp-front/plugins/base.rb,
lib/amp-front/dispatch/runner.rb,
lib/amp-front/dispatch/commands/base.rb,
lib/amp-front/support/module_extensions.rb,
lib/amp-front/dispatch/commands/validations.rb
Overview
Licensing Information # # The following code is licensed, as standalone code, under # the Ruby License, unless otherwise directed within the code. # # For information on the license of this code when distributed # with and used in conjunction with the other modules in the # Amp project, please see the root-level LICENSE file. # # © Michael J. Edgar and Ari Brown, 2009-2010 # #
Defined Under Namespace
Modules: Command, Dispatch, Help, ModuleExtensions, Plugins
Constant Summary collapse
- VERSION =
'0.0.1'- VERSION_TITLE =
'Koyaanisqatsi'